@@ -527,13 +527,8 @@ class DenMune():
         labels_dic = {}
         self.train_pred = pred_list [:self.train_sz]
         self.test_pred = pred_list[self.train_sz:]
-        labels_dic ['train'] = self.train_pred
-        labels_dic ['test'] = self.test_pred
-        
-      
        
-
-
+        
         if self.test_data is not None:
             self.labels_pred = np.append(self.train_pred, self.test_pred, axis = 0)
         else:
@@ -581,6 +576,10 @@ class DenMune():
                    print ('Plotting augmented data (train & test)')  
                self.plot_clusters(show_plots=show_plots, show_noise=show_noise, data_type='augmented')
            """
+
+        labels_dic ['train'] = self.train_pred
+        labels_dic ['test'] = self.test_pred
+
         if self.data_indicator  == 1:
             return labels_dic, None
         else:
@@ -776,8 +775,6 @@ class DenMune():
             else:
                 fake_clusters+=1
               
-
-    
         self.analyzer["n_clusters"]["detected"]=   num_of_clusters - fake_clusters  
         
         return  labels       
@@ -817,7 +814,9 @@ class DenMune():
             elif data_type == 'test':
               plt.scatter(data2[self.train_sz:].T[0], data2[self.train_sz:].T[1], c=colors2, **plot_kwds, marker='o') 
             elif data_type == 'augmented':
-              plt.scatter(data2.T[0], data2.T[1], c=colors2, **plot_kwds, marker='o')   
+              plt.scatter(data2.T[0], data2.T[1], c=colors2, **plot_kwds, marker='o')  
+            elif data_type == 'ground':
+              plt.scatter(data2[:self.train_sz].T[0], data2[:self.train_sz].T[1], c=colors2, **plot_kwds, marker='o')
           else:
               if data_type == 'train':
                 plt.scatter(self.data[:self.train_sz].T[0], self.data[:self.train_sz].T[1], c=colors, **plot_kwds, marker='o')
@@ -833,9 +832,14 @@ class DenMune():
           frame.axes.get_xaxis().set_visible(False)
           frame.axes.get_yaxis().set_visible(False)
           if show_plots:
+            if self.prop_step:
+              prop_folder = 'propagation'
+              if not os.path.exists (prop_folder):
+                os.mkdir(prop_folder)
+              plt.savefig(prop_folder + '/' + str(self.prop_step)+'.png')
             plt.show()
-          #plt.clf()    # this is a must to clear figures if you plot continously
-          
+            #plt.clf()    # this is a must to clear figures if you plot continously
+         
         return 0
     
     
@@ -891,4 +895,7 @@ class DenMune():
                         for z in subsubdic:
                             #print('4', 'key:', z , 'value:', subsubdic[z], 'parent:', v)
                             creat_TreefromDict(self, tree, subsubdic, z, parent=v)
-        tree.show()    
\ No newline at end of file
+        tree.show()    
+ 
+        
+        
\ No newline at end of file
